@@ -1,12 +1,7 @@
-#!/usr/bin/env python
-import only
-import public
+__all__ = ['app']
 
 from ._run import _run
 
-
-@only.osx
-@public.add
 def app(appname, applescript, background=False):
     """execute applescript `tell application "VLC" ...`"""
     cmd = """tell app "%s"
